using System;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;

namespace AccelerometerTest
{
    /// <summary>
    /// Accelerometer
    /// </summary>
    public class LSM303DLM_Accelerometer : I2CBase
    {
        private class Register
        {
            public const byte CTRL_REG1_A = 0x20;
            public const byte OUT_X_L_A = 0x28;
            public const byte OUT_X_H_A = 0x29;
            public const byte OUT_Y_L_A = 0x2a;
            public const byte OUT_Y_H_A = 0x2b;
            public const byte OUT_Z_L_A = 0x2c;
            public const byte OUT_Z_H_A = 0x2d;
        }

        private I2CDevice.Configuration _config;
        private const double _scale = 1000;

        public LSM303DLM_Accelerometer()
        {
            _config = new I2CDevice.Configuration(0x18, 400);

            EnableNormalPowerAllAxes();
        }

        private void EnableNormalPowerAllAxes()
        {
            // 0x27 = 00100111
            Write(Register.CTRL_REG1_A, 0x27);
        }

        private double GetAccelerationInGs(byte high, byte low)
        {
            // 12 bit - left justified

            var data = (Int16)(((Read(high) << 8) | Read(low)) >> 4);

            return (((double)(data)) / _scale);
        }

        public double GetX()
        {
            return GetAccelerationInGs(Register.OUT_X_H_A, Register.OUT_X_L_A);
        }

        public double GetY()
        {
            return GetAccelerationInGs(Register.OUT_Y_H_A, Register.OUT_Y_L_A);
        }

        public double GetZ()
        {
            return GetAccelerationInGs(Register.OUT_Z_H_A, Register.OUT_Z_L_A);
        }

        public override I2CDevice.Configuration Config
        {
            get { return _config; }
        }
    }
}
